# coding: utf-8

"""
    Wavefront REST API

    <p>The Wavefront REST API enables you to interact with Wavefront servers using standard REST API tools. You can use the REST API to automate commonly executed operations such as automatically tagging sources.</p><p>When you make REST API calls outside the Wavefront REST API documentation you must add the header \"Authorization: Bearer &lt;&lt;API-TOKEN&gt;&gt;\" to your HTTP requests.</p>  # noqa: E501

    OpenAPI spec version: v2
    Contact: chitimba@wavefront.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from wavefront_api_client.api_client import ApiClient


class UserApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def add_user_to_user_groups(self, id, **kwargs):  # noqa: E501
        """Adds specific user groups to the user or service account  # noqa: E501

          # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.add_user_to_user_groups(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :param list[str] body: The list of user groups that should be added to the account
        :return: UserModel
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.add_user_to_user_groups_with_http_info(id, **kwargs)  # noqa: E501
        else:
            (data) = self.add_user_to_user_groups_with_http_info(id, **kwargs)  # noqa: E501
            return data

    def add_user_to_user_groups_with_http_info(self, id, **kwargs):  # noqa: E501
        """Adds specific user groups to the user or service account  # noqa: E501

          # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.add_user_to_user_groups_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :param list[str] body: The list of user groups that should be added to the account
        :return: UserModel
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id', 'body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method add_user_to_user_groups" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in params or
                                                       params['id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `id` when calling `add_user_to_user_groups`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/api/v2/user/{id}/addUserGroups', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='UserModel',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def create_user(self, **kwargs):  # noqa: E501
        """Creates an user if the user doesn't already exist.  # noqa: E501

          # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_user(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param bool send_email: Whether to send email notification to the user, if created.  Default: false
        :param UserToCreate body: Example Body:  <pre>{   \"emailAddress\": \"user@example.com\",   \"groups\": [     \"user_management\"   ],   \"userGroups\": [     \"8b23136b-ecd2-4cb5-8c92-62477dcc4090\"   ],   \"ingestionPolicyId\": \"ingestionPolicyId\",   \"roles\": [     \"Role\"   ] }</pre>
        :return: UserModel
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.create_user_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.create_user_with_http_info(**kwargs)  # noqa: E501
            return data

    def create_user_with_http_info(self, **kwargs):  # noqa: E501
        """Creates an user if the user doesn't already exist.  # noqa: E501

          # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_user_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param bool send_email: Whether to send email notification to the user, if created.  Default: false
        :param UserToCreate body: Example Body:  <pre>{   \"emailAddress\": \"user@example.com\",   \"groups\": [     \"user_management\"   ],   \"userGroups\": [     \"8b23136b-ecd2-4cb5-8c92-62477dcc4090\"   ],   \"ingestionPolicyId\": \"ingestionPolicyId\",   \"roles\": [     \"Role\"   ] }</pre>
        :return: UserModel
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['send_email', 'body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_user" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'send_email' in params:
            query_params.append(('sendEmail', params['send_email']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/api/v2/user', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='UserModel',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def delete_multiple_users(self, **kwargs):  # noqa: E501
        """Deletes multiple users or service accounts  # noqa: E501

          # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_multiple_users(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param list[str] body: identifiers of list of users which should be deleted
        :return: ResponseContainerListString
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.delete_multiple_users_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.delete_multiple_users_with_http_info(**kwargs)  # noqa: E501
            return data

    def delete_multiple_users_with_http_info(self, **kwargs):  # noqa: E501
        """Deletes multiple users or service accounts  # noqa: E501

          # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_multiple_users_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param list[str] body: identifiers of list of users which should be deleted
        :return: ResponseContainerListString
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_multiple_users" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/api/v2/user/deleteUsers', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ResponseContainerListString',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def delete_user(self, id, **kwargs):  # noqa: E501
        """Deletes a user or service account identified by id  # noqa: E501

          # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_user(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.delete_user_with_http_info(id, **kwargs)  # noqa: E501
        else:
            (data) = self.delete_user_with_http_info(id, **kwargs)  # noqa: E501
            return data

    def delete_user_with_http_info(self, id, **kwargs):  # noqa: E501
        """Deletes a user or service account identified by id  # noqa: E501

          # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_user_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_user" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in params or
                                                       params['id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `id` when calling `delete_user`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/api/v2/user/{id}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_all_users(self, **kwargs):  # noqa: E501
        """Get all users  # noqa: E501

        Returns all users  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_all_users(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: list[UserModel]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_all_users_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_all_users_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_all_users_with_http_info(self, **kwargs):  # noqa: E501
        """Get all users  # noqa: E501

        Returns all users  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_all_users_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: list[UserModel]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = []  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_all_users" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/api/v2/user', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[UserModel]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_user(self, id, **kwargs):  # noqa: E501
        """Retrieves a user by identifier (email address)  # noqa: E501

          # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_user(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :return: UserModel
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_user_with_http_info(id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_user_with_http_info(id, **kwargs)  # noqa: E501
            return data

    def get_user_with_http_info(self, id, **kwargs):  # noqa: E501
        """Retrieves a user by identifier (email address)  # noqa: E501

          # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_user_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :return: UserModel
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_user" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in params or
                                                       params['id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `id` when calling `get_user`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/api/v2/user/{id}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='UserModel',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_user_business_functions(self, id, **kwargs):  # noqa: E501
        """Returns business functions of a specific user or service account.  # noqa: E501

          # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_user_business_functions(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :return: UserModel
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_user_business_functions_with_http_info(id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_user_business_functions_with_http_info(id, **kwargs)  # noqa: E501
            return data

    def get_user_business_functions_with_http_info(self, id, **kwargs):  # noqa: E501
        """Returns business functions of a specific user or service account.  # noqa: E501

          # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_user_business_functions_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :return: UserModel
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_user_business_functions" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in params or
                                                       params['id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `id` when calling `get_user_business_functions`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/api/v2/user/{id}/businessFunctions', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='UserModel',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def grant_permission_to_users(self, permission, **kwargs):  # noqa: E501
        """Grants a specific permission to multiple users or service accounts  # noqa: E501

          # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.grant_permission_to_users(permission, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str permission: Permission to grant to the users. Please note that 'host_tag_management' is the equivalent of the 'Source Tag Management' permission (required)
        :param list[str] body: List of users which should be granted by specified permission
        :return: UserModel
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.grant_permission_to_users_with_http_info(permission, **kwargs)  # noqa: E501
        else:
            (data) = self.grant_permission_to_users_with_http_info(permission, **kwargs)  # noqa: E501
            return data

    def grant_permission_to_users_with_http_info(self, permission, **kwargs):  # noqa: E501
        """Grants a specific permission to multiple users or service accounts  # noqa: E501

          # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.grant_permission_to_users_with_http_info(permission, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str permission: Permission to grant to the users. Please note that 'host_tag_management' is the equivalent of the 'Source Tag Management' permission (required)
        :param list[str] body: List of users which should be granted by specified permission
        :return: UserModel
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['permission', 'body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method grant_permission_to_users" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'permission' is set
        if self.api_client.client_side_validation and ('permission' not in params or
                                                       params['permission'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `permission` when calling `grant_permission_to_users`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'permission' in params:
            path_params['permission'] = params['permission']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/api/v2/user/grant/{permission}', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='UserModel',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def grant_user_permission(self, id, **kwargs):  # noqa: E501
        """Grants a specific permission to user or service account  # noqa: E501

          # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.grant_user_permission(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :param str group: Permission group to grant to the account. Please note that 'host_tag_management' is the equivalent of the 'Source Tag Management' permission
        :return: UserModel
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.grant_user_permission_with_http_info(id, **kwargs)  # noqa: E501
        else:
            (data) = self.grant_user_permission_with_http_info(id, **kwargs)  # noqa: E501
            return data

    def grant_user_permission_with_http_info(self, id, **kwargs):  # noqa: E501
        """Grants a specific permission to user or service account  # noqa: E501

          # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.grant_user_permission_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :param str group: Permission group to grant to the account. Please note that 'host_tag_management' is the equivalent of the 'Source Tag Management' permission
        :return: UserModel
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id', 'group']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method grant_user_permission" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in params or
                                                       params['id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `id` when calling `grant_user_permission`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}
        if 'group' in params:
            form_params.append(('group', params['group']))  # noqa: E501

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/x-www-form-urlencoded'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/api/v2/user/{id}/grant', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='UserModel',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def invite_users(self, **kwargs):  # noqa: E501
        """Invite users with given user groups and permissions.  # noqa: E501

          # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.invite_users(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param list[UserToCreate] body: Example Body:  <pre>[ {   \"emailAddress\": \"user@example.com\",   \"groups\": [     \"user_management\"   ],   \"userGroups\": [     \"8b23136b-ecd2-4cb5-8c92-62477dcc4090\"   ],   \"ingestionPolicyId\": \"ingestionPolicyId\",   \"roles\": [     \"Role\"   ] } ]</pre>
        :return: UserModel
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.invite_users_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.invite_users_with_http_info(**kwargs)  # noqa: E501
            return data

    def invite_users_with_http_info(self, **kwargs):  # noqa: E501
        """Invite users with given user groups and permissions.  # noqa: E501

          # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.invite_users_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param list[UserToCreate] body: Example Body:  <pre>[ {   \"emailAddress\": \"user@example.com\",   \"groups\": [     \"user_management\"   ],   \"userGroups\": [     \"8b23136b-ecd2-4cb5-8c92-62477dcc4090\"   ],   \"ingestionPolicyId\": \"ingestionPolicyId\",   \"roles\": [     \"Role\"   ] } ]</pre>
        :return: UserModel
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method invite_users" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/api/v2/user/invite', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='UserModel',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def remove_user_from_user_groups(self, id, **kwargs):  # noqa: E501
        """Removes specific user groups from the user or service account  # noqa: E501

          # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.remove_user_from_user_groups(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :param list[str] body: The list of user groups that should be removed from the account
        :return: UserModel
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.remove_user_from_user_groups_with_http_info(id, **kwargs)  # noqa: E501
        else:
            (data) = self.remove_user_from_user_groups_with_http_info(id, **kwargs)  # noqa: E501
            return data

    def remove_user_from_user_groups_with_http_info(self, id, **kwargs):  # noqa: E501
        """Removes specific user groups from the user or service account  # noqa: E501

          # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.remove_user_from_user_groups_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :param list[str] body: The list of user groups that should be removed from the account
        :return: UserModel
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id', 'body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method remove_user_from_user_groups" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in params or
                                                       params['id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `id` when calling `remove_user_from_user_groups`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/api/v2/user/{id}/removeUserGroups', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='UserModel',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def revoke_permission_from_users(self, permission, **kwargs):  # noqa: E501
        """Revokes a specific permission from multiple users or service accounts  # noqa: E501

          # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.revoke_permission_from_users(permission, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str permission: Permission to revoke from the accounts. Please note that 'host_tag_management' is the equivalent of the 'Source Tag Management' permission (required)
        :param list[str] body: List of users or service accounts which should be revoked by specified permission
        :return: UserModel
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.revoke_permission_from_users_with_http_info(permission, **kwargs)  # noqa: E501
        else:
            (data) = self.revoke_permission_from_users_with_http_info(permission, **kwargs)  # noqa: E501
            return data

    def revoke_permission_from_users_with_http_info(self, permission, **kwargs):  # noqa: E501
        """Revokes a specific permission from multiple users or service accounts  # noqa: E501

          # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.revoke_permission_from_users_with_http_info(permission, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str permission: Permission to revoke from the accounts. Please note that 'host_tag_management' is the equivalent of the 'Source Tag Management' permission (required)
        :param list[str] body: List of users or service accounts which should be revoked by specified permission
        :return: UserModel
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['permission', 'body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method revoke_permission_from_users" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'permission' is set
        if self.api_client.client_side_validation and ('permission' not in params or
                                                       params['permission'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `permission` when calling `revoke_permission_from_users`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'permission' in params:
            path_params['permission'] = params['permission']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/api/v2/user/revoke/{permission}', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='UserModel',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def revoke_user_permission(self, id, **kwargs):  # noqa: E501
        """Revokes a specific permission from user or service account  # noqa: E501

          # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.revoke_user_permission(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :param str group:
        :return: UserModel
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.revoke_user_permission_with_http_info(id, **kwargs)  # noqa: E501
        else:
            (data) = self.revoke_user_permission_with_http_info(id, **kwargs)  # noqa: E501
            return data

    def revoke_user_permission_with_http_info(self, id, **kwargs):  # noqa: E501
        """Revokes a specific permission from user or service account  # noqa: E501

          # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.revoke_user_permission_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :param str group:
        :return: UserModel
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id', 'group']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method revoke_user_permission" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in params or
                                                       params['id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `id` when calling `revoke_user_permission`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}
        if 'group' in params:
            form_params.append(('group', params['group']))  # noqa: E501

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/x-www-form-urlencoded'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/api/v2/user/{id}/revoke', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='UserModel',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def update_user(self, id, **kwargs):  # noqa: E501
        """Update user with given user groups, permissions and ingestion policy.  # noqa: E501

          # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_user(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :param UserRequestDTO body: Example Body:  <pre>{   \"identifier\": \"user@example.com\",   \"groups\": [     \"user_management\"   ],   \"userGroups\": [     \"8b23136b-ecd2-4cb5-8c92-62477dcc4090\"   ],   \"ingestionPolicyId\": \"ingestionPolicyId\",   \"roles\": [     \"Role\"   ] }</pre>
        :return: UserModel
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.update_user_with_http_info(id, **kwargs)  # noqa: E501
        else:
            (data) = self.update_user_with_http_info(id, **kwargs)  # noqa: E501
            return data

    def update_user_with_http_info(self, id, **kwargs):  # noqa: E501
        """Update user with given user groups, permissions and ingestion policy.  # noqa: E501

          # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_user_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :param UserRequestDTO body: Example Body:  <pre>{   \"identifier\": \"user@example.com\",   \"groups\": [     \"user_management\"   ],   \"userGroups\": [     \"8b23136b-ecd2-4cb5-8c92-62477dcc4090\"   ],   \"ingestionPolicyId\": \"ingestionPolicyId\",   \"roles\": [     \"Role\"   ] }</pre>
        :return: UserModel
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id', 'body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_user" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in params or
                                                       params['id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `id` when calling `update_user`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/api/v2/user/{id}', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='UserModel',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def validate_users(self, **kwargs):  # noqa: E501
        """Returns valid users and service accounts, also invalid identifiers from the given list  # noqa: E501

          # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.validate_users(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param list[str] body:
        :return: ResponseContainerValidatedUsersDTO
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.validate_users_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.validate_users_with_http_info(**kwargs)  # noqa: E501
            return data

    def validate_users_with_http_info(self, **kwargs):  # noqa: E501
        """Returns valid users and service accounts, also invalid identifiers from the given list  # noqa: E501

          # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.validate_users_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param list[str] body:
        :return: ResponseContainerValidatedUsersDTO
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method validate_users" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/api/v2/user/validateUsers', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ResponseContainerValidatedUsersDTO',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Wavefront REST API

    <p>The Wavefront REST API enables you to interact with Wavefront servers using standard REST API tools. You can use the REST API to automate commonly executed operations such as automatically tagging sources.</p><p>When you make REST API calls outside the Wavefront REST API documentation you must add the header \"Authorization: Bearer &lt;&lt;API-TOKEN&gt;&gt;\" to your HTTP requests.</p>  # noqa: E501

    OpenAPI spec version: v2
    Contact: chitimba@wavefront.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from wavefront_api_client.configuration import Configuration


class IntegrationStatus(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'alert_statuses': 'dict(str, str)',
        'content_status': 'str',
        'install_status': 'str',
        'metric_statuses': 'dict(str, MetricStatus)'
    }

    attribute_map = {
        'alert_statuses': 'alertStatuses',
        'content_status': 'contentStatus',
        'install_status': 'installStatus',
        'metric_statuses': 'metricStatuses'
    }

    def __init__(self, alert_statuses=None, content_status=None, install_status=None, metric_statuses=None, _configuration=None):  # noqa: E501
        """IntegrationStatus - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._alert_statuses = None
        self._content_status = None
        self._install_status = None
        self._metric_statuses = None
        self.discriminator = None

        if alert_statuses is not None:
            self.alert_statuses = alert_statuses
        if content_status is not None:
            self.content_status = content_status
        if install_status is not None:
            self.install_status = install_status
        if metric_statuses is not None:
            self.metric_statuses = metric_statuses

    @property
    def alert_statuses(self):
        """Gets the alert_statuses of this IntegrationStatus.  # noqa: E501

        A Map from the ids of the alerts contained in this integration to their install status.  The install status can take on one of three values, `VISIBLE`, `HIDDEN`, and `NOT_LOADED`  # noqa: E501

        :return: The alert_statuses of this IntegrationStatus.  # noqa: E501
        :rtype: dict(str, str)
        """
        return self._alert_statuses

    @alert_statuses.setter
    def alert_statuses(self, alert_statuses):
        """Sets the alert_statuses of this IntegrationStatus.

        A Map from the ids of the alerts contained in this integration to their install status.  The install status can take on one of three values, `VISIBLE`, `HIDDEN`, and `NOT_LOADED`  # noqa: E501

        :param alert_statuses: The alert_statuses of this IntegrationStatus.  # noqa: E501
        :type: dict(str, str)
        """
        allowed_values = ["VISIBLE", "HIDDEN", "NOT_LOADED"]  # noqa: E501
        if (self._configuration.client_side_validation and
                not set(alert_statuses.keys()).issubset(set(allowed_values))):  # noqa: E501
            raise ValueError(
                "Invalid keys in `alert_statuses` [{0}], must be a subset of [{1}]"  # noqa: E501
                .format(", ".join(map(str, set(alert_statuses.keys()) - set(allowed_values))),  # noqa: E501
                        ", ".join(map(str, allowed_values)))
            )

        self._alert_statuses = alert_statuses

    @property
    def content_status(self):
        """Gets the content_status of this IntegrationStatus.  # noqa: E501

        Status of integration content, e.g. dashboards  # noqa: E501

        :return: The content_status of this IntegrationStatus.  # noqa: E501
        :rtype: str
        """
        return self._content_status

    @content_status.setter
    def content_status(self, content_status):
        """Sets the content_status of this IntegrationStatus.

        Status of integration content, e.g. dashboards  # noqa: E501

        :param content_status: The content_status of this IntegrationStatus.  # noqa: E501
        :type: str
        """
        allowed_values = ["INVALID", "NOT_LOADED", "HIDDEN", "VISIBLE"]  # noqa: E501
        if (self._configuration.client_side_validation and
                content_status not in allowed_values):
            raise ValueError(
                "Invalid value for `content_status` ({0}), must be one of {1}"  # noqa: E501
                .format(content_status, allowed_values)
            )

        self._content_status = content_status

    @property
    def install_status(self):
        """Gets the install_status of this IntegrationStatus.  # noqa: E501

        Whether the customer or an automated process has installed the dashboards for this integration  # noqa: E501

        :return: The install_status of this IntegrationStatus.  # noqa: E501
        :rtype: str
        """
        return self._install_status

    @install_status.setter
    def install_status(self, install_status):
        """Sets the install_status of this IntegrationStatus.

        Whether the customer or an automated process has installed the dashboards for this integration  # noqa: E501

        :param install_status: The install_status of this IntegrationStatus.  # noqa: E501
        :type: str
        """
        allowed_values = ["UNDECIDED", "UNINSTALLED", "INSTALLED"]  # noqa: E501
        if (self._configuration.client_side_validation and
                install_status not in allowed_values):
            raise ValueError(
                "Invalid value for `install_status` ({0}), must be one of {1}"  # noqa: E501
                .format(install_status, allowed_values)
            )

        self._install_status = install_status

    @property
    def metric_statuses(self):
        """Gets the metric_statuses of this IntegrationStatus.  # noqa: E501

        A Map from names of the required metrics to an object representing their reporting status.  The reporting status object has 3 boolean fields denoting whether the metric has been received during the corresponding time period: `ever`, `recentExceptNow`, and `now`.  `now` is on the order of a few hours, and `recentExceptNow` is on the order of the past few days, excluding the period considered to be `now`.  # noqa: E501

        :return: The metric_statuses of this IntegrationStatus.  # noqa: E501
        :rtype: dict(str, MetricStatus)
        """
        return self._metric_statuses

    @metric_statuses.setter
    def metric_statuses(self, metric_statuses):
        """Sets the metric_statuses of this IntegrationStatus.

        A Map from names of the required metrics to an object representing their reporting status.  The reporting status object has 3 boolean fields denoting whether the metric has been received during the corresponding time period: `ever`, `recentExceptNow`, and `now`.  `now` is on the order of a few hours, and `recentExceptNow` is on the order of the past few days, excluding the period considered to be `now`.  # noqa: E501

        :param metric_statuses: The metric_statuses of this IntegrationStatus.  # noqa: E501
        :type: dict(str, MetricStatus)
        """

        self._metric_statuses = metric_statuses

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(IntegrationStatus, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, IntegrationStatus):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, IntegrationStatus):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Wavefront REST API

    <p>The Wavefront REST API enables you to interact with Wavefront servers using standard REST API tools. You can use the REST API to automate commonly executed operations such as automatically tagging sources.</p><p>When you make REST API calls outside the Wavefront REST API documentation you must add the header \"Authorization: Bearer &lt;&lt;API-TOKEN&gt;&gt;\" to your HTTP requests.</p>  # noqa: E501

    OpenAPI spec version: v2
    Contact: chitimba@wavefront.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import wavefront_api_client
from wavefront_api_client.api.metrics_policy_api import MetricsPolicyApi  # noqa: E501
from wavefront_api_client.rest import ApiException


class TestMetricsPolicyApi(unittest.TestCase):
    """MetricsPolicyApi unit test stubs"""

    def setUp(self):
        self.api = wavefront_api_client.api.metrics_policy_api.MetricsPolicyApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_metrics_policy(self):
        """Test case for get_metrics_policy

        Get the metrics policy  # noqa: E501
        """
        pass

    def test_get_metrics_policy_by_version(self):
        """Test case for get_metrics_policy_by_version

        Get a specific historical version of a metrics policy  # noqa: E501
        """
        pass

    def test_get_metrics_policy_history(self):
        """Test case for get_metrics_policy_history

        Get the version history of metrics policy  # noqa: E501
        """
        pass

    def test_revert_metrics_policy_by_version(self):
        """Test case for revert_metrics_policy_by_version

        Revert to a specific historical version of a metrics policy  # noqa: E501
        """
        pass

    def test_update_metrics_policy(self):
        """Test case for update_metrics_policy

        Update the metrics policy  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Wavefront REST API

    <p>The Wavefront REST API enables you to interact with Wavefront servers using standard REST API tools. You can use the REST API to automate commonly executed operations such as automatically tagging sources.</p><p>When you make REST API calls outside the Wavefront REST API documentation you must add the header \"Authorization: Bearer &lt;&lt;API-TOKEN&gt;&gt;\" to your HTTP requests.</p>  # noqa: E501

    OpenAPI spec version: v2
    Contact: chitimba@wavefront.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from wavefront_api_client.configuration import Configuration


class DashboardParameterValue(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'allow_all': 'bool',
        'default_value': 'str',
        'description': 'str',
        'dynamic_field_type': 'str',
        'hide_from_view': 'bool',
        'label': 'str',
        'multivalue': 'bool',
        'order': 'int',
        'parameter_type': 'str',
        'query_value': 'str',
        'reverse_dyn_sort': 'bool',
        'tag_key': 'str',
        'tags_black_list_regex': 'str',
        'value_ordering': 'list[str]',
        'values_to_readable_strings': 'dict(str, str)'
    }

    attribute_map = {
        'allow_all': 'allowAll',
        'default_value': 'defaultValue',
        'description': 'description',
        'dynamic_field_type': 'dynamicFieldType',
        'hide_from_view': 'hideFromView',
        'label': 'label',
        'multivalue': 'multivalue',
        'order': 'order',
        'parameter_type': 'parameterType',
        'query_value': 'queryValue',
        'reverse_dyn_sort': 'reverseDynSort',
        'tag_key': 'tagKey',
        'tags_black_list_regex': 'tagsBlackListRegex',
        'value_ordering': 'valueOrdering',
        'values_to_readable_strings': 'valuesToReadableStrings'
    }

    def __init__(self, allow_all=None, default_value=None, description=None, dynamic_field_type=None, hide_from_view=None, label=None, multivalue=None, order=None, parameter_type=None, query_value=None, reverse_dyn_sort=None, tag_key=None, tags_black_list_regex=None, value_ordering=None, values_to_readable_strings=None, _configuration=None):  # noqa: E501
        """DashboardParameterValue - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._allow_all = None
        self._default_value = None
        self._description = None
        self._dynamic_field_type = None
        self._hide_from_view = None
        self._label = None
        self._multivalue = None
        self._order = None
        self._parameter_type = None
        self._query_value = None
        self._reverse_dyn_sort = None
        self._tag_key = None
        self._tags_black_list_regex = None
        self._value_ordering = None
        self._values_to_readable_strings = None
        self.discriminator = None

        if allow_all is not None:
            self.allow_all = allow_all
        if default_value is not None:
            self.default_value = default_value
        if description is not None:
            self.description = description
        if dynamic_field_type is not None:
            self.dynamic_field_type = dynamic_field_type
        if hide_from_view is not None:
            self.hide_from_view = hide_from_view
        if label is not None:
            self.label = label
        if multivalue is not None:
            self.multivalue = multivalue
        if order is not None:
            self.order = order
        if parameter_type is not None:
            self.parameter_type = parameter_type
        if query_value is not None:
            self.query_value = query_value
        if reverse_dyn_sort is not None:
            self.reverse_dyn_sort = reverse_dyn_sort
        if tag_key is not None:
            self.tag_key = tag_key
        if tags_black_list_regex is not None:
            self.tags_black_list_regex = tags_black_list_regex
        if value_ordering is not None:
            self.value_ordering = value_ordering
        if values_to_readable_strings is not None:
            self.values_to_readable_strings = values_to_readable_strings

    @property
    def allow_all(self):
        """Gets the allow_all of this DashboardParameterValue.  # noqa: E501


        :return: The allow_all of this DashboardParameterValue.  # noqa: E501
        :rtype: bool
        """
        return self._allow_all

    @allow_all.setter
    def allow_all(self, allow_all):
        """Sets the allow_all of this DashboardParameterValue.


        :param allow_all: The allow_all of this DashboardParameterValue.  # noqa: E501
        :type: bool
        """

        self._allow_all = allow_all

    @property
    def default_value(self):
        """Gets the default_value of this DashboardParameterValue.  # noqa: E501


        :return: The default_value of this DashboardParameterValue.  # noqa: E501
        :rtype: str
        """
        return self._default_value

    @default_value.setter
    def default_value(self, default_value):
        """Sets the default_value of this DashboardParameterValue.


        :param default_value: The default_value of this DashboardParameterValue.  # noqa: E501
        :type: str
        """

        self._default_value = default_value

    @property
    def description(self):
        """Gets the description of this DashboardParameterValue.  # noqa: E501


        :return: The description of this DashboardParameterValue.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this DashboardParameterValue.


        :param description: The description of this DashboardParameterValue.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def dynamic_field_type(self):
        """Gets the dynamic_field_type of this DashboardParameterValue.  # noqa: E501


        :return: The dynamic_field_type of this DashboardParameterValue.  # noqa: E501
        :rtype: str
        """
        return self._dynamic_field_type

    @dynamic_field_type.setter
    def dynamic_field_type(self, dynamic_field_type):
        """Sets the dynamic_field_type of this DashboardParameterValue.


        :param dynamic_field_type: The dynamic_field_type of this DashboardParameterValue.  # noqa: E501
        :type: str
        """
        allowed_values = ["SOURCE", "SOURCE_TAG", "METRIC_NAME", "TAG_KEY", "MATCHING_SOURCE_TAG"]  # noqa: E501
        if (self._configuration.client_side_validation and
                dynamic_field_type not in allowed_values):
            raise ValueError(
                "Invalid value for `dynamic_field_type` ({0}), must be one of {1}"  # noqa: E501
                .format(dynamic_field_type, allowed_values)
            )

        self._dynamic_field_type = dynamic_field_type

    @property
    def hide_from_view(self):
        """Gets the hide_from_view of this DashboardParameterValue.  # noqa: E501


        :return: The hide_from_view of this DashboardParameterValue.  # noqa: E501
        :rtype: bool
        """
        return self._hide_from_view

    @hide_from_view.setter
    def hide_from_view(self, hide_from_view):
        """Sets the hide_from_view of this DashboardParameterValue.


        :param hide_from_view: The hide_from_view of this DashboardParameterValue.  # noqa: E501
        :type: bool
        """

        self._hide_from_view = hide_from_view

    @property
    def label(self):
        """Gets the label of this DashboardParameterValue.  # noqa: E501


        :return: The label of this DashboardParameterValue.  # noqa: E501
        :rtype: str
        """
        return self._label

    @label.setter
    def label(self, label):
        """Sets the label of this DashboardParameterValue.


        :param label: The label of this DashboardParameterValue.  # noqa: E501
        :type: str
        """

        self._label = label

    @property
    def multivalue(self):
        """Gets the multivalue of this DashboardParameterValue.  # noqa: E501


        :return: The multivalue of this DashboardParameterValue.  # noqa: E501
        :rtype: bool
        """
        return self._multivalue

    @multivalue.setter
    def multivalue(self, multivalue):
        """Sets the multivalue of this DashboardParameterValue.


        :param multivalue: The multivalue of this DashboardParameterValue.  # noqa: E501
        :type: bool
        """

        self._multivalue = multivalue

    @property
    def order(self):
        """Gets the order of this DashboardParameterValue.  # noqa: E501


        :return: The order of this DashboardParameterValue.  # noqa: E501
        :rtype: int
        """
        return self._order

    @order.setter
    def order(self, order):
        """Sets the order of this DashboardParameterValue.


        :param order: The order of this DashboardParameterValue.  # noqa: E501
        :type: int
        """

        self._order = order

    @property
    def parameter_type(self):
        """Gets the parameter_type of this DashboardParameterValue.  # noqa: E501


        :return: The parameter_type of this DashboardParameterValue.  # noqa: E501
        :rtype: str
        """
        return self._parameter_type

    @parameter_type.setter
    def parameter_type(self, parameter_type):
        """Sets the parameter_type of this DashboardParameterValue.


        :param parameter_type: The parameter_type of this DashboardParameterValue.  # noqa: E501
        :type: str
        """
        allowed_values = ["SIMPLE", "LIST", "DYNAMIC"]  # noqa: E501
        if (self._configuration.client_side_validation and
                parameter_type not in allowed_values):
            raise ValueError(
                "Invalid value for `parameter_type` ({0}), must be one of {1}"  # noqa: E501
                .format(parameter_type, allowed_values)
            )

        self._parameter_type = parameter_type

    @property
    def query_value(self):
        """Gets the query_value of this DashboardParameterValue.  # noqa: E501


        :return: The query_value of this DashboardParameterValue.  # noqa: E501
        :rtype: str
        """
        return self._query_value

    @query_value.setter
    def query_value(self, query_value):
        """Sets the query_value of this DashboardParameterValue.


        :param query_value: The query_value of this DashboardParameterValue.  # noqa: E501
        :type: str
        """

        self._query_value = query_value

    @property
    def reverse_dyn_sort(self):
        """Gets the reverse_dyn_sort of this DashboardParameterValue.  # noqa: E501

        Whether to reverse alphabetically sort the returned result.  # noqa: E501

        :return: The reverse_dyn_sort of this DashboardParameterValue.  # noqa: E501
        :rtype: bool
        """
        return self._reverse_dyn_sort

    @reverse_dyn_sort.setter
    def reverse_dyn_sort(self, reverse_dyn_sort):
        """Sets the reverse_dyn_sort of this DashboardParameterValue.

        Whether to reverse alphabetically sort the returned result.  # noqa: E501

        :param reverse_dyn_sort: The reverse_dyn_sort of this DashboardParameterValue.  # noqa: E501
        :type: bool
        """

        self._reverse_dyn_sort = reverse_dyn_sort

    @property
    def tag_key(self):
        """Gets the tag_key of this DashboardParameterValue.  # noqa: E501


        :return: The tag_key of this DashboardParameterValue.  # noqa: E501
        :rtype: str
        """
        return self._tag_key

    @tag_key.setter
    def tag_key(self, tag_key):
        """Sets the tag_key of this DashboardParameterValue.


        :param tag_key: The tag_key of this DashboardParameterValue.  # noqa: E501
        :type: str
        """

        self._tag_key = tag_key

    @property
    def tags_black_list_regex(self):
        """Gets the tags_black_list_regex of this DashboardParameterValue.  # noqa: E501

        The regular expression to filter out source tags from the Current Values list.  # noqa: E501

        :return: The tags_black_list_regex of this DashboardParameterValue.  # noqa: E501
        :rtype: str
        """
        return self._tags_black_list_regex

    @tags_black_list_regex.setter
    def tags_black_list_regex(self, tags_black_list_regex):
        """Sets the tags_black_list_regex of this DashboardParameterValue.

        The regular expression to filter out source tags from the Current Values list.  # noqa: E501

        :param tags_black_list_regex: The tags_black_list_regex of this DashboardParameterValue.  # noqa: E501
        :type: str
        """

        self._tags_black_list_regex = tags_black_list_regex

    @property
    def value_ordering(self):
        """Gets the value_ordering of this DashboardParameterValue.  # noqa: E501


        :return: The value_ordering of this DashboardParameterValue.  # noqa: E501
        :rtype: list[str]
        """
        return self._value_ordering

    @value_ordering.setter
    def value_ordering(self, value_ordering):
        """Sets the value_ordering of this DashboardParameterValue.


        :param value_ordering: The value_ordering of this DashboardParameterValue.  # noqa: E501
        :type: list[str]
        """

        self._value_ordering = value_ordering

    @property
    def values_to_readable_strings(self):
        """Gets the values_to_readable_strings of this DashboardParameterValue.  # noqa: E501


        :return: The values_to_readable_strings of this DashboardParameterValue.  # noqa: E501
        :rtype: dict(str, str)
        """
        return self._values_to_readable_strings

    @values_to_readable_strings.setter
    def values_to_readable_strings(self, values_to_readable_strings):
        """Sets the values_to_readable_strings of this DashboardParameterValue.


        :param values_to_readable_strings: The values_to_readable_strings of this DashboardParameterValue.  # noqa: E501
        :type: dict(str, str)
        """

        self._values_to_readable_strings = values_to_readable_strings

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(DashboardParameterValue, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DashboardParameterValue):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, DashboardParameterValue):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Wavefront REST API

    <p>The Wavefront REST API enables you to interact with Wavefront servers using standard REST API tools. You can use the REST API to automate commonly executed operations such as automatically tagging sources.</p><p>When you make REST API calls outside the Wavefront REST API documentation you must add the header \"Authorization: Bearer &lt;&lt;API-TOKEN&gt;&gt;\" to your HTTP requests.</p>  # noqa: E501

    OpenAPI spec version: v2
    Contact: chitimba@wavefront.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from wavefront_api_client.configuration import Configuration


class RelatedAnomaly(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'chart_hash': 'str',
        'chart_link': 'str',
        'col': 'int',
        'created_epoch_millis': 'int',
        'creator_id': 'str',
        'customer': 'str',
        'dashboard_id': 'str',
        'deleted': 'bool',
        'end_ms': 'int',
        'hosts_used': 'list[str]',
        'id': 'str',
        'image_link': 'str',
        'metrics_used': 'list[str]',
        'model': 'str',
        'original_stripes': 'list[Stripe]',
        'param_hash': 'str',
        'query_hash': 'str',
        '_query_params': 'dict(str, str)',
        'related_data': 'RelatedData',
        'row': 'int',
        'section': 'int',
        'start_ms': 'int',
        'updated_epoch_millis': 'int',
        'updated_ms': 'int',
        'updater_id': 'str'
    }

    attribute_map = {
        'chart_hash': 'chartHash',
        'chart_link': 'chartLink',
        'col': 'col',
        'created_epoch_millis': 'createdEpochMillis',
        'creator_id': 'creatorId',
        'customer': 'customer',
        'dashboard_id': 'dashboardId',
        'deleted': 'deleted',
        'end_ms': 'endMs',
        'hosts_used': 'hostsUsed',
        'id': 'id',
        'image_link': 'imageLink',
        'metrics_used': 'metricsUsed',
        'model': 'model',
        'original_stripes': 'originalStripes',
        'param_hash': 'paramHash',
        'query_hash': 'queryHash',
        '_query_params': 'queryParams',
        'related_data': 'relatedData',
        'row': 'row',
        'section': 'section',
        'start_ms': 'startMs',
        'updated_epoch_millis': 'updatedEpochMillis',
        'updated_ms': 'updatedMs',
        'updater_id': 'updaterId'
    }

    def __init__(self, chart_hash=None, chart_link=None, col=None, created_epoch_millis=None, creator_id=None, customer=None, dashboard_id=None, deleted=None, end_ms=None, hosts_used=None, id=None, image_link=None, metrics_used=None, model=None, original_stripes=None, param_hash=None, query_hash=None, _query_params=None, related_data=None, row=None, section=None, start_ms=None, updated_epoch_millis=None, updated_ms=None, updater_id=None, _configuration=None):  # noqa: E501
        """RelatedAnomaly - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._chart_hash = None
        self._chart_link = None
        self._col = None
        self._created_epoch_millis = None
        self._creator_id = None
        self._customer = None
        self._dashboard_id = None
        self._deleted = None
        self._end_ms = None
        self._hosts_used = None
        self._id = None
        self._image_link = None
        self._metrics_used = None
        self._model = None
        self._original_stripes = None
        self._param_hash = None
        self._query_hash = None
        self.__query_params = None
        self._related_data = None
        self._row = None
        self._section = None
        self._start_ms = None
        self._updated_epoch_millis = None
        self._updated_ms = None
        self._updater_id = None
        self.discriminator = None

        self.chart_hash = chart_hash
        if chart_link is not None:
            self.chart_link = chart_link
        self.col = col
        if created_epoch_millis is not None:
            self.created_epoch_millis = created_epoch_millis
        if creator_id is not None:
            self.creator_id = creator_id
        if customer is not None:
            self.customer = customer
        self.dashboard_id = dashboard_id
        if deleted is not None:
            self.deleted = deleted
        self.end_ms = end_ms
        if hosts_used is not None:
            self.hosts_used = hosts_used
        if id is not None:
            self.id = id
        if image_link is not None:
            self.image_link = image_link
        if metrics_used is not None:
            self.metrics_used = metrics_used
        if model is not None:
            self.model = model
        if original_stripes is not None:
            self.original_stripes = original_stripes
        self.param_hash = param_hash
        self.query_hash = query_hash
        self._query_params = _query_params
        if related_data is not None:
            self.related_data = related_data
        self.row = row
        self.section = section
        self.start_ms = start_ms
        if updated_epoch_millis is not None:
            self.updated_epoch_millis = updated_epoch_millis
        self.updated_ms = updated_ms
        if updater_id is not None:
            self.updater_id = updater_id

    @property
    def chart_hash(self):
        """Gets the chart_hash of this RelatedAnomaly.  # noqa: E501

        chart hash(as unique identifier) for this anomaly  # noqa: E501

        :return: The chart_hash of this RelatedAnomaly.  # noqa: E501
        :rtype: str
        """
        return self._chart_hash

    @chart_hash.setter
    def chart_hash(self, chart_hash):
        """Sets the chart_hash of this RelatedAnomaly.

        chart hash(as unique identifier) for this anomaly  # noqa: E501

        :param chart_hash: The chart_hash of this RelatedAnomaly.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and chart_hash is None:
            raise ValueError("Invalid value for `chart_hash`, must not be `None`")  # noqa: E501

        self._chart_hash = chart_hash

    @property
    def chart_link(self):
        """Gets the chart_link of this RelatedAnomaly.  # noqa: E501

        chart link for this anomaly  # noqa: E501

        :return: The chart_link of this RelatedAnomaly.  # noqa: E501
        :rtype: str
        """
        return self._chart_link

    @chart_link.setter
    def chart_link(self, chart_link):
        """Sets the chart_link of this RelatedAnomaly.

        chart link for this anomaly  # noqa: E501

        :param chart_link: The chart_link of this RelatedAnomaly.  # noqa: E501
        :type: str
        """

        self._chart_link = chart_link

    @property
    def col(self):
        """Gets the col of this RelatedAnomaly.  # noqa: E501

        column number for this anomaly  # noqa: E501

        :return: The col of this RelatedAnomaly.  # noqa: E501
        :rtype: int
        """
        return self._col

    @col.setter
    def col(self, col):
        """Sets the col of this RelatedAnomaly.

        column number for this anomaly  # noqa: E501

        :param col: The col of this RelatedAnomaly.  # noqa: E501
        :type: int
        """
        if self._configuration.client_side_validation and col is None:
            raise ValueError("Invalid value for `col`, must not be `None`")  # noqa: E501

        self._col = col

    @property
    def created_epoch_millis(self):
        """Gets the created_epoch_millis of this RelatedAnomaly.  # noqa: E501


        :return: The created_epoch_millis of this RelatedAnomaly.  # noqa: E501
        :rtype: int
        """
        return self._created_epoch_millis

    @created_epoch_millis.setter
    def created_epoch_millis(self, created_epoch_millis):
        """Sets the created_epoch_millis of this RelatedAnomaly.


        :param created_epoch_millis: The created_epoch_millis of this RelatedAnomaly.  # noqa: E501
        :type: int
        """

        self._created_epoch_millis = created_epoch_millis

    @property
    def creator_id(self):
        """Gets the creator_id of this RelatedAnomaly.  # noqa: E501


        :return: The creator_id of this RelatedAnomaly.  # noqa: E501
        :rtype: str
        """
        return self._creator_id

    @creator_id.setter
    def creator_id(self, creator_id):
        """Sets the creator_id of this RelatedAnomaly.


        :param creator_id: The creator_id of this RelatedAnomaly.  # noqa: E501
        :type: str
        """

        self._creator_id = creator_id

    @property
    def customer(self):
        """Gets the customer of this RelatedAnomaly.  # noqa: E501

        id of the customer to which this anomaly belongs  # noqa: E501

        :return: The customer of this RelatedAnomaly.  # noqa: E501
        :rtype: str
        """
        return self._customer

    @customer.setter
    def customer(self, customer):
        """Sets the customer of this RelatedAnomaly.

        id of the customer to which this anomaly belongs  # noqa: E501

        :param customer: The customer of this RelatedAnomaly.  # noqa: E501
        :type: str
        """

        self._customer = customer

    @property
    def dashboard_id(self):
        """Gets the dashboard_id of this RelatedAnomaly.  # noqa: E501

        dashboard id for this anomaly  # noqa: E501

        :return: The dashboard_id of this RelatedAnomaly.  # noqa: E501
        :rtype: str
        """
        return self._dashboard_id

    @dashboard_id.setter
    def dashboard_id(self, dashboard_id):
        """Sets the dashboard_id of this RelatedAnomaly.

        dashboard id for this anomaly  # noqa: E501

        :param dashboard_id: The dashboard_id of this RelatedAnomaly.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and dashboard_id is None:
            raise ValueError("Invalid value for `dashboard_id`, must not be `None`")  # noqa: E501

        self._dashboard_id = dashboard_id

    @property
    def deleted(self):
        """Gets the deleted of this RelatedAnomaly.  # noqa: E501


        :return: The deleted of this RelatedAnomaly.  # noqa: E501
        :rtype: bool
        """
        return self._deleted

    @deleted.setter
    def deleted(self, deleted):
        """Sets the deleted of this RelatedAnomaly.


        :param deleted: The deleted of this RelatedAnomaly.  # noqa: E501
        :type: bool
        """

        self._deleted = deleted

    @property
    def end_ms(self):
        """Gets the end_ms of this RelatedAnomaly.  # noqa: E501

        endMs for this anomaly  # noqa: E501

        :return: The end_ms of this RelatedAnomaly.  # noqa: E501
        :rtype: int
        """
        return self._end_ms

    @end_ms.setter
    def end_ms(self, end_ms):
        """Sets the end_ms of this RelatedAnomaly.

        endMs for this anomaly  # noqa: E501

        :param end_ms: The end_ms of this RelatedAnomaly.  # noqa: E501
        :type: int
        """
        if self._configuration.client_side_validation and end_ms is None:
            raise ValueError("Invalid value for `end_ms`, must not be `None`")  # noqa: E501

        self._end_ms = end_ms

    @property
    def hosts_used(self):
        """Gets the hosts_used of this RelatedAnomaly.  # noqa: E501

        list of hosts affected of this anomaly  # noqa: E501

        :return: The hosts_used of this RelatedAnomaly.  # noqa: E501
        :rtype: list[str]
        """
        return self._hosts_used

    @hosts_used.setter
    def hosts_used(self, hosts_used):
        """Sets the hosts_used of this RelatedAnomaly.

        list of hosts affected of this anomaly  # noqa: E501

        :param hosts_used: The hosts_used of this RelatedAnomaly.  # noqa: E501
        :type: list[str]
        """

        self._hosts_used = hosts_used

    @property
    def id(self):
        """Gets the id of this RelatedAnomaly.  # noqa: E501

        unique id that defines this anomaly  # noqa: E501

        :return: The id of this RelatedAnomaly.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this RelatedAnomaly.

        unique id that defines this anomaly  # noqa: E501

        :param id: The id of this RelatedAnomaly.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def image_link(self):
        """Gets the image_link of this RelatedAnomaly.  # noqa: E501

        image link for this anomaly  # noqa: E501

        :return: The image_link of this RelatedAnomaly.  # noqa: E501
        :rtype: str
        """
        return self._image_link

    @image_link.setter
    def image_link(self, image_link):
        """Sets the image_link of this RelatedAnomaly.

        image link for this anomaly  # noqa: E501

        :param image_link: The image_link of this RelatedAnomaly.  # noqa: E501
        :type: str
        """

        self._image_link = image_link

    @property
    def metrics_used(self):
        """Gets the metrics_used of this RelatedAnomaly.  # noqa: E501

        list of metrics used of this anomaly  # noqa: E501

        :return: The metrics_used of this RelatedAnomaly.  # noqa: E501
        :rtype: list[str]
        """
        return self._metrics_used

    @metrics_used.setter
    def metrics_used(self, metrics_used):
        """Sets the metrics_used of this RelatedAnomaly.

        list of metrics used of this anomaly  # noqa: E501

        :param metrics_used: The metrics_used of this RelatedAnomaly.  # noqa: E501
        :type: list[str]
        """

        self._metrics_used = metrics_used

    @property
    def model(self):
        """Gets the model of this RelatedAnomaly.  # noqa: E501

        model for this anomaly  # noqa: E501

        :return: The model of this RelatedAnomaly.  # noqa: E501
        :rtype: str
        """
        return self._model

    @model.setter
    def model(self, model):
        """Sets the model of this RelatedAnomaly.

        model for this anomaly  # noqa: E501

        :param model: The model of this RelatedAnomaly.  # noqa: E501
        :type: str
        """

        self._model = model

    @property
    def original_stripes(self):
        """Gets the original_stripes of this RelatedAnomaly.  # noqa: E501

        list of originalStripe belongs to this anomaly  # noqa: E501

        :return: The original_stripes of this RelatedAnomaly.  # noqa: E501
        :rtype: list[Stripe]
        """
        return self._original_stripes

    @original_stripes.setter
    def original_stripes(self, original_stripes):
        """Sets the original_stripes of this RelatedAnomaly.

        list of originalStripe belongs to this anomaly  # noqa: E501

        :param original_stripes: The original_stripes of this RelatedAnomaly.  # noqa: E501
        :type: list[Stripe]
        """

        self._original_stripes = original_stripes

    @property
    def param_hash(self):
        """Gets the param_hash of this RelatedAnomaly.  # noqa: E501

        param hash for this anomaly  # noqa: E501

        :return: The param_hash of this RelatedAnomaly.  # noqa: E501
        :rtype: str
        """
        return self._param_hash

    @param_hash.setter
    def param_hash(self, param_hash):
        """Sets the param_hash of this RelatedAnomaly.

        param hash for this anomaly  # noqa: E501

        :param param_hash: The param_hash of this RelatedAnomaly.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and param_hash is None:
            raise ValueError("Invalid value for `param_hash`, must not be `None`")  # noqa: E501

        self._param_hash = param_hash

    @property
    def query_hash(self):
        """Gets the query_hash of this RelatedAnomaly.  # noqa: E501

        query hash for this anomaly  # noqa: E501

        :return: The query_hash of this RelatedAnomaly.  # noqa: E501
        :rtype: str
        """
        return self._query_hash

    @query_hash.setter
    def query_hash(self, query_hash):
        """Sets the query_hash of this RelatedAnomaly.

        query hash for this anomaly  # noqa: E501

        :param query_hash: The query_hash of this RelatedAnomaly.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and query_hash is None:
            raise ValueError("Invalid value for `query_hash`, must not be `None`")  # noqa: E501

        self._query_hash = query_hash

    @property
    def _query_params(self):
        """Gets the _query_params of this RelatedAnomaly.  # noqa: E501

        map of query params belongs to this anomaly  # noqa: E501

        :return: The _query_params of this RelatedAnomaly.  # noqa: E501
        :rtype: dict(str, str)
        """
        return self.__query_params

    @_query_params.setter
    def _query_params(self, _query_params):
        """Sets the _query_params of this RelatedAnomaly.

        map of query params belongs to this anomaly  # noqa: E501

        :param _query_params: The _query_params of this RelatedAnomaly.  # noqa: E501
        :type: dict(str, str)
        """
        if self._configuration.client_side_validation and _query_params is None:
            raise ValueError("Invalid value for `_query_params`, must not be `None`")  # noqa: E501

        self.__query_params = _query_params

    @property
    def related_data(self):
        """Gets the related_data of this RelatedAnomaly.  # noqa: E501

        Data concerning how this anomaly is related to the event in the request  # noqa: E501

        :return: The related_data of this RelatedAnomaly.  # noqa: E501
        :rtype: RelatedData
        """
        return self._related_data

    @related_data.setter
    def related_data(self, related_data):
        """Sets the related_data of this RelatedAnomaly.

        Data concerning how this anomaly is related to the event in the request  # noqa: E501

        :param related_data: The related_data of this RelatedAnomaly.  # noqa: E501
        :type: RelatedData
        """

        self._related_data = related_data

    @property
    def row(self):
        """Gets the row of this RelatedAnomaly.  # noqa: E501

        row number for this anomaly  # noqa: E501

        :return: The row of this RelatedAnomaly.  # noqa: E501
        :rtype: int
        """
        return self._row

    @row.setter
    def row(self, row):
        """Sets the row of this RelatedAnomaly.

        row number for this anomaly  # noqa: E501

        :param row: The row of this RelatedAnomaly.  # noqa: E501
        :type: int
        """
        if self._configuration.client_side_validation and row is None:
            raise ValueError("Invalid value for `row`, must not be `None`")  # noqa: E501

        self._row = row

    @property
    def section(self):
        """Gets the section of this RelatedAnomaly.  # noqa: E501

        section number for this anomaly  # noqa: E501

        :return: The section of this RelatedAnomaly.  # noqa: E501
        :rtype: int
        """
        return self._section

    @section.setter
    def section(self, section):
        """Sets the section of this RelatedAnomaly.

        section number for this anomaly  # noqa: E501

        :param section: The section of this RelatedAnomaly.  # noqa: E501
        :type: int
        """
        if self._configuration.client_side_validation and section is None:
            raise ValueError("Invalid value for `section`, must not be `None`")  # noqa: E501

        self._section = section

    @property
    def start_ms(self):
        """Gets the start_ms of this RelatedAnomaly.  # noqa: E501

        startMs for this anomaly  # noqa: E501

        :return: The start_ms of this RelatedAnomaly.  # noqa: E501
        :rtype: int
        """
        return self._start_ms

    @start_ms.setter
    def start_ms(self, start_ms):
        """Sets the start_ms of this RelatedAnomaly.

        startMs for this anomaly  # noqa: E501

        :param start_ms: The start_ms of this RelatedAnomaly.  # noqa: E501
        :type: int
        """
        if self._configuration.client_side_validation and start_ms is None:
            raise ValueError("Invalid value for `start_ms`, must not be `None`")  # noqa: E501

        self._start_ms = start_ms

    @property
    def updated_epoch_millis(self):
        """Gets the updated_epoch_millis of this RelatedAnomaly.  # noqa: E501


        :return: The updated_epoch_millis of this RelatedAnomaly.  # noqa: E501
        :rtype: int
        """
        return self._updated_epoch_millis

    @updated_epoch_millis.setter
    def updated_epoch_millis(self, updated_epoch_millis):
        """Sets the updated_epoch_millis of this RelatedAnomaly.


        :param updated_epoch_millis: The updated_epoch_millis of this RelatedAnomaly.  # noqa: E501
        :type: int
        """

        self._updated_epoch_millis = updated_epoch_millis

    @property
    def updated_ms(self):
        """Gets the updated_ms of this RelatedAnomaly.  # noqa: E501

        updateMs for this anomaly  # noqa: E501

        :return: The updated_ms of this RelatedAnomaly.  # noqa: E501
        :rtype: int
        """
        return self._updated_ms

    @updated_ms.setter
    def updated_ms(self, updated_ms):
        """Sets the updated_ms of this RelatedAnomaly.

        updateMs for this anomaly  # noqa: E501

        :param updated_ms: The updated_ms of this RelatedAnomaly.  # noqa: E501
        :type: int
        """
        if self._configuration.client_side_validation and updated_ms is None:
            raise ValueError("Invalid value for `updated_ms`, must not be `None`")  # noqa: E501

        self._updated_ms = updated_ms

    @property
    def updater_id(self):
        """Gets the updater_id of this RelatedAnomaly.  # noqa: E501


        :return: The updater_id of this RelatedAnomaly.  # noqa: E501
        :rtype: str
        """
        return self._updater_id

    @updater_id.setter
    def updater_id(self, updater_id):
        """Sets the updater_id of this RelatedAnomaly.


        :param updater_id: The updater_id of this RelatedAnomaly.  # noqa: E501
        :type: str
        """

        self._updater_id = updater_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(RelatedAnomaly, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RelatedAnomaly):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, RelatedAnomaly):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Wavefront REST API

    <p>The Wavefront REST API enables you to interact with Wavefront servers using standard REST API tools. You can use the REST API to automate commonly executed operations such as automatically tagging sources.</p><p>When you make REST API calls outside the Wavefront REST API documentation you must add the header \"Authorization: Bearer &lt;&lt;API-TOKEN&gt;&gt;\" to your HTTP requests.</p>  # noqa: E501

    OpenAPI spec version: v2
    Contact: chitimba@wavefront.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from wavefront_api_client.configuration import Configuration


class CloudIntegration(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'additional_tags': 'dict(str, str)',
        'app_dynamics': 'AppDynamicsConfiguration',
        'azure': 'AzureConfiguration',
        'azure_activity_log': 'AzureActivityLogConfiguration',
        'cloud_trail': 'CloudTrailConfiguration',
        'cloud_watch': 'CloudWatchConfiguration',
        'created_epoch_millis': 'int',
        'creator_id': 'str',
        'deleted': 'bool',
        'disabled': 'bool',
        'ec2': 'EC2Configuration',
        'force_save': 'bool',
        'gcp': 'GCPConfiguration',
        'gcp_billing': 'GCPBillingConfiguration',
        'id': 'str',
        'in_trash': 'bool',
        'last_error': 'str',
        'last_error_event': 'Event',
        'last_error_ms': 'int',
        'last_metric_count': 'int',
        'last_processing_timestamp': 'int',
        'last_processor_id': 'str',
        'last_received_data_point_ms': 'int',
        'name': 'str',
        'new_relic': 'NewRelicConfiguration',
        'reuse_external_id_credential': 'str',
        'service': 'str',
        'service_refresh_rate_in_mins': 'int',
        'tesla': 'TeslaConfiguration',
        'updated_epoch_millis': 'int',
        'updater_id': 'str'
    }

    attribute_map = {
        'additional_tags': 'additionalTags',
        'app_dynamics': 'appDynamics',
        'azure': 'azure',
        'azure_activity_log': 'azureActivityLog',
        'cloud_trail': 'cloudTrail',
        'cloud_watch': 'cloudWatch',
        'created_epoch_millis': 'createdEpochMillis',
        'creator_id': 'creatorId',
        'deleted': 'deleted',
        'disabled': 'disabled',
        'ec2': 'ec2',
        'force_save': 'forceSave',
        'gcp': 'gcp',
        'gcp_billing': 'gcpBilling',
        'id': 'id',
        'in_trash': 'inTrash',
        'last_error': 'lastError',
        'last_error_event': 'lastErrorEvent',
        'last_error_ms': 'lastErrorMs',
        'last_metric_count': 'lastMetricCount',
        'last_processing_timestamp': 'lastProcessingTimestamp',
        'last_processor_id': 'lastProcessorId',
        'last_received_data_point_ms': 'lastReceivedDataPointMs',
        'name': 'name',
        'new_relic': 'newRelic',
        'reuse_external_id_credential': 'reuseExternalIdCredential',
        'service': 'service',
        'service_refresh_rate_in_mins': 'serviceRefreshRateInMins',
        'tesla': 'tesla',
        'updated_epoch_millis': 'updatedEpochMillis',
        'updater_id': 'updaterId'
    }

    def __init__(self, additional_tags=None, app_dynamics=None, azure=None, azure_activity_log=None, cloud_trail=None, cloud_watch=None, created_epoch_millis=None, creator_id=None, deleted=None, disabled=None, ec2=None, force_save=None, gcp=None, gcp_billing=None, id=None, in_trash=None, last_error=None, last_error_event=None, last_error_ms=None, last_metric_count=None, last_processing_timestamp=None, last_processor_id=None, last_received_data_point_ms=None, name=None, new_relic=None, reuse_external_id_credential=None, service=None, service_refresh_rate_in_mins=None, tesla=None, updated_epoch_millis=None, updater_id=None, _configuration=None):  # noqa: E501
        """CloudIntegration - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._additional_tags = None
        self._app_dynamics = None
        self._azure = None
        self._azure_activity_log = None
        self._cloud_trail = None
        self._cloud_watch = None
        self._created_epoch_millis = None
        self._creator_id = None
        self._deleted = None
        self._disabled = None
        self._ec2 = None
        self._force_save = None
        self._gcp = None
        self._gcp_billing = None
        self._id = None
        self._in_trash = None
        self._last_error = None
        self._last_error_event = None
        self._last_error_ms = None
        self._last_metric_count = None
        self._last_processing_timestamp = None
        self._last_processor_id = None
        self._last_received_data_point_ms = None
        self._name = None
        self._new_relic = None
        self._reuse_external_id_credential = None
        self._service = None
        self._service_refresh_rate_in_mins = None
        self._tesla = None
        self._updated_epoch_millis = None
        self._updater_id = None
        self.discriminator = None

        if additional_tags is not None:
            self.additional_tags = additional_tags
        if app_dynamics is not None:
            self.app_dynamics = app_dynamics
        if azure is not None:
            self.azure = azure
        if azure_activity_log is not None:
            self.azure_activity_log = azure_activity_log
        if cloud_trail is not None:
            self.cloud_trail = cloud_trail
        if cloud_watch is not None:
            self.cloud_watch = cloud_watch
        if created_epoch_millis is not None:
            self.created_epoch_millis = created_epoch_millis
        if creator_id is not None:
            self.creator_id = creator_id
        if deleted is not None:
            self.deleted = deleted
        if disabled is not None:
            self.disabled = disabled
        if ec2 is not None:
            self.ec2 = ec2
        if force_save is not None:
            self.force_save = force_save
        if gcp is not None:
            self.gcp = gcp
        if gcp_billing is not None:
            self.gcp_billing = gcp_billing
        if id is not None:
            self.id = id
        if in_trash is not None:
            self.in_trash = in_trash
        if last_error is not None:
            self.last_error = last_error
        if last_error_event is not None:
            self.last_error_event = last_error_event
        if last_error_ms is not None:
            self.last_error_ms = last_error_ms
        if last_metric_count is not None:
            self.last_metric_count = last_metric_count
        if last_processing_timestamp is not None:
            self.last_processing_timestamp = last_processing_timestamp
        if last_processor_id is not None:
            self.last_processor_id = last_processor_id
        if last_received_data_point_ms is not None:
            self.last_received_data_point_ms = last_received_data_point_ms
        self.name = name
        if new_relic is not None:
            self.new_relic = new_relic
        if reuse_external_id_credential is not None:
            self.reuse_external_id_credential = reuse_external_id_credential
        self.service = service
        if service_refresh_rate_in_mins is not None:
            self.service_refresh_rate_in_mins = service_refresh_rate_in_mins
        if tesla is not None:
            self.tesla = tesla
        if updated_epoch_millis is not None:
            self.updated_epoch_millis = updated_epoch_millis
        if updater_id is not None:
            self.updater_id = updater_id

    @property
    def additional_tags(self):
        """Gets the additional_tags of this CloudIntegration.  # noqa: E501

        A list of point tag key-values to add to every point ingested using this integration  # noqa: E501

        :return: The additional_tags of this CloudIntegration.  # noqa: E501
        :rtype: dict(str, str)
        """
        return self._additional_tags

    @additional_tags.setter
    def additional_tags(self, additional_tags):
        """Sets the additional_tags of this CloudIntegration.

        A list of point tag key-values to add to every point ingested using this integration  # noqa: E501

        :param additional_tags: The additional_tags of this CloudIntegration.  # noqa: E501
        :type: dict(str, str)
        """

        self._additional_tags = additional_tags

    @property
    def app_dynamics(self):
        """Gets the app_dynamics of this CloudIntegration.  # noqa: E501


        :return: The app_dynamics of this CloudIntegration.  # noqa: E501
        :rtype: AppDynamicsConfiguration
        """
        return self._app_dynamics

    @app_dynamics.setter
    def app_dynamics(self, app_dynamics):
        """Sets the app_dynamics of this CloudIntegration.


        :param app_dynamics: The app_dynamics of this CloudIntegration.  # noqa: E501
        :type: AppDynamicsConfiguration
        """

        self._app_dynamics = app_dynamics

    @property
    def azure(self):
        """Gets the azure of this CloudIntegration.  # noqa: E501


        :return: The azure of this CloudIntegration.  # noqa: E501
        :rtype: AzureConfiguration
        """
        return self._azure

    @azure.setter
    def azure(self, azure):
        """Sets the azure of this CloudIntegration.


        :param azure: The azure of this CloudIntegration.  # noqa: E501
        :type: AzureConfiguration
        """

        self._azure = azure

    @property
    def azure_activity_log(self):
        """Gets the azure_activity_log of this CloudIntegration.  # noqa: E501


        :return: The azure_activity_log of this CloudIntegration.  # noqa: E501
        :rtype: AzureActivityLogConfiguration
        """
        return self._azure_activity_log

    @azure_activity_log.setter
    def azure_activity_log(self, azure_activity_log):
        """Sets the azure_activity_log of this CloudIntegration.


        :param azure_activity_log: The azure_activity_log of this CloudIntegration.  # noqa: E501
        :type: AzureActivityLogConfiguration
        """

        self._azure_activity_log = azure_activity_log

    @property
    def cloud_trail(self):
        """Gets the cloud_trail of this CloudIntegration.  # noqa: E501


        :return: The cloud_trail of this CloudIntegration.  # noqa: E501
        :rtype: CloudTrailConfiguration
        """
        return self._cloud_trail

    @cloud_trail.setter
    def cloud_trail(self, cloud_trail):
        """Sets the cloud_trail of this CloudIntegration.


        :param cloud_trail: The cloud_trail of this CloudIntegration.  # noqa: E501
        :type: CloudTrailConfiguration
        """

        self._cloud_trail = cloud_trail

    @property
    def cloud_watch(self):
        """Gets the cloud_watch of this CloudIntegration.  # noqa: E501


        :return: The cloud_watch of this CloudIntegration.  # noqa: E501
        :rtype: CloudWatchConfiguration
        """
        return self._cloud_watch

    @cloud_watch.setter
    def cloud_watch(self, cloud_watch):
        """Sets the cloud_watch of this CloudIntegration.


        :param cloud_watch: The cloud_watch of this CloudIntegration.  # noqa: E501
        :type: CloudWatchConfiguration
        """

        self._cloud_watch = cloud_watch

    @property
    def created_epoch_millis(self):
        """Gets the created_epoch_millis of this CloudIntegration.  # noqa: E501


        :return: The created_epoch_millis of this CloudIntegration.  # noqa: E501
        :rtype: int
        """
        return self._created_epoch_millis

    @created_epoch_millis.setter
    def created_epoch_millis(self, created_epoch_millis):
        """Sets the created_epoch_millis of this CloudIntegration.


        :param created_epoch_millis: The created_epoch_millis of this CloudIntegration.  # noqa: E501
        :type: int
        """

        self._created_epoch_millis = created_epoch_millis

    @property
    def creator_id(self):
        """Gets the creator_id of this CloudIntegration.  # noqa: E501


        :return: The creator_id of this CloudIntegration.  # noqa: E501
        :rtype: str
        """
        return self._creator_id

    @creator_id.setter
    def creator_id(self, creator_id):
        """Sets the creator_id of this CloudIntegration.


        :param creator_id: The creator_id of this CloudIntegration.  # noqa: E501
        :type: str
        """

        self._creator_id = creator_id

    @property
    def deleted(self):
        """Gets the deleted of this CloudIntegration.  # noqa: E501


        :return: The deleted of this CloudIntegration.  # noqa: E501
        :rtype: bool
        """
        return self._deleted

    @deleted.setter
    def deleted(self, deleted):
        """Sets the deleted of this CloudIntegration.


        :param deleted: The deleted of this CloudIntegration.  # noqa: E501
        :type: bool
        """

        self._deleted = deleted

    @property
    def disabled(self):
        """Gets the disabled of this CloudIntegration.  # noqa: E501

        True when an aws credential failed to authenticate.  # noqa: E501

        :return: The disabled of this CloudIntegration.  # noqa: E501
        :rtype: bool
        """
        return self._disabled

    @disabled.setter
    def disabled(self, disabled):
        """Sets the disabled of this CloudIntegration.

        True when an aws credential failed to authenticate.  # noqa: E501

        :param disabled: The disabled of this CloudIntegration.  # noqa: E501
        :type: bool
        """

        self._disabled = disabled

    @property
    def ec2(self):
        """Gets the ec2 of this CloudIntegration.  # noqa: E501


        :return: The ec2 of this CloudIntegration.  # noqa: E501
        :rtype: EC2Configuration
        """
        return self._ec2

    @ec2.setter
    def ec2(self, ec2):
        """Sets the ec2 of this CloudIntegration.


        :param ec2: The ec2 of this CloudIntegration.  # noqa: E501
        :type: EC2Configuration
        """

        self._ec2 = ec2

    @property
    def force_save(self):
        """Gets the force_save of this CloudIntegration.  # noqa: E501


        :return: The force_save of this CloudIntegration.  # noqa: E501
        :rtype: bool
        """
        return self._force_save

    @force_save.setter
    def force_save(self, force_save):
        """Sets the force_save of this CloudIntegration.


        :param force_save: The force_save of this CloudIntegration.  # noqa: E501
        :type: bool
        """

        self._force_save = force_save

    @property
    def gcp(self):
        """Gets the gcp of this CloudIntegration.  # noqa: E501


        :return: The gcp of this CloudIntegration.  # noqa: E501
        :rtype: GCPConfiguration
        """
        return self._gcp

    @gcp.setter
    def gcp(self, gcp):
        """Sets the gcp of this CloudIntegration.


        :param gcp: The gcp of this CloudIntegration.  # noqa: E501
        :type: GCPConfiguration
        """

        self._gcp = gcp

    @property
    def gcp_billing(self):
        """Gets the gcp_billing of this CloudIntegration.  # noqa: E501


        :return: The gcp_billing of this CloudIntegration.  # noqa: E501
        :rtype: GCPBillingConfiguration
        """
        return self._gcp_billing

    @gcp_billing.setter
    def gcp_billing(self, gcp_billing):
        """Sets the gcp_billing of this CloudIntegration.


        :param gcp_billing: The gcp_billing of this CloudIntegration.  # noqa: E501
        :type: GCPBillingConfiguration
        """

        self._gcp_billing = gcp_billing

    @property
    def id(self):
        """Gets the id of this CloudIntegration.  # noqa: E501


        :return: The id of this CloudIntegration.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this CloudIntegration.


        :param id: The id of this CloudIntegration.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def in_trash(self):
        """Gets the in_trash of this CloudIntegration.  # noqa: E501


        :return: The in_trash of this CloudIntegration.  # noqa: E501
        :rtype: bool
        """
        return self._in_trash

    @in_trash.setter
    def in_trash(self, in_trash):
        """Sets the in_trash of this CloudIntegration.


        :param in_trash: The in_trash of this CloudIntegration.  # noqa: E501
        :type: bool
        """

        self._in_trash = in_trash

    @property
    def last_error(self):
        """Gets the last_error of this CloudIntegration.  # noqa: E501

        Digest of the last error encountered by Wavefront servers when fetching data using this integration  # noqa: E501

        :return: The last_error of this CloudIntegration.  # noqa: E501
        :rtype: str
        """
        return self._last_error

    @last_error.setter
    def last_error(self, last_error):
        """Sets the last_error of this CloudIntegration.

        Digest of the last error encountered by Wavefront servers when fetching data using this integration  # noqa: E501

        :param last_error: The last_error of this CloudIntegration.  # noqa: E501
        :type: str
        """

        self._last_error = last_error

    @property
    def last_error_event(self):
        """Gets the last_error_event of this CloudIntegration.  # noqa: E501


        :return: The last_error_event of this CloudIntegration.  # noqa: E501
        :rtype: Event
        """
        return self._last_error_event

    @last_error_event.setter
    def last_error_event(self, last_error_event):
        """Sets the last_error_event of this CloudIntegration.


        :param last_error_event: The last_error_event of this CloudIntegration.  # noqa: E501
        :type: Event
        """

        self._last_error_event = last_error_event

    @property
    def last_error_ms(self):
        """Gets the last_error_ms of this CloudIntegration.  # noqa: E501

        Time, in epoch millis, of the last error encountered by Wavefront servers when fetching data using this integration  # noqa: E501

        :return: The last_error_ms of this CloudIntegration.  # noqa: E501
        :rtype: int
        """
        return self._last_error_ms

    @last_error_ms.setter
    def last_error_ms(self, last_error_ms):
        """Sets the last_error_ms of this CloudIntegration.

        Time, in epoch millis, of the last error encountered by Wavefront servers when fetching data using this integration  # noqa: E501

        :param last_error_ms: The last_error_ms of this CloudIntegration.  # noqa: E501
        :type: int
        """

        self._last_error_ms = last_error_ms

    @property
    def last_metric_count(self):
        """Gets the last_metric_count of this CloudIntegration.  # noqa: E501

        Number of metrics / events ingested by this integration the last time it ran  # noqa: E501

        :return: The last_metric_count of this CloudIntegration.  # noqa: E501
        :rtype: int
        """
        return self._last_metric_count

    @last_metric_count.setter
    def last_metric_count(self, last_metric_count):
        """Sets the last_metric_count of this CloudIntegration.

        Number of metrics / events ingested by this integration the last time it ran  # noqa: E501

        :param last_metric_count: The last_metric_count of this CloudIntegration.  # noqa: E501
        :type: int
        """

        self._last_metric_count = last_metric_count

    @property
    def last_processing_timestamp(self):
        """Gets the last_processing_timestamp of this CloudIntegration.  # noqa: E501

        Time, in epoch millis, that this integration was last processed  # noqa: E501

        :return: The last_processing_timestamp of this CloudIntegration.  # noqa: E501
        :rtype: int
        """
        return self._last_processing_timestamp

    @last_processing_timestamp.setter
    def last_processing_timestamp(self, last_processing_timestamp):
        """Sets the last_processing_timestamp of this CloudIntegration.

        Time, in epoch millis, that this integration was last processed  # noqa: E501

        :param last_processing_timestamp: The last_processing_timestamp of this CloudIntegration.  # noqa: E501
        :type: int
        """

        self._last_processing_timestamp = last_processing_timestamp

    @property
    def last_processor_id(self):
        """Gets the last_processor_id of this CloudIntegration.  # noqa: E501

        Opaque id of the last Wavefront integrations service to act on this integration  # noqa: E501

        :return: The last_processor_id of this CloudIntegration.  # noqa: E501
        :rtype: str
        """
        return self._last_processor_id

    @last_processor_id.setter
    def last_processor_id(self, last_processor_id):
        """Sets the last_processor_id of this CloudIntegration.

        Opaque id of the last Wavefront integrations service to act on this integration  # noqa: E501

        :param last_processor_id: The last_processor_id of this CloudIntegration.  # noqa: E501
        :type: str
        """

        self._last_processor_id = last_processor_id

    @property
    def last_received_data_point_ms(self):
        """Gets the last_received_data_point_ms of this CloudIntegration.  # noqa: E501

        Time that this integration last received a data point, in epoch millis  # noqa: E501

        :return: The last_received_data_point_ms of this CloudIntegration.  # noqa: E501
        :rtype: int
        """
        return self._last_received_data_point_ms

    @last_received_data_point_ms.setter
    def last_received_data_point_ms(self, last_received_data_point_ms):
        """Sets the last_received_data_point_ms of this CloudIntegration.

        Time that this integration last received a data point, in epoch millis  # noqa: E501

        :param last_received_data_point_ms: The last_received_data_point_ms of this CloudIntegration.  # noqa: E501
        :type: int
        """

        self._last_received_data_point_ms = last_received_data_point_ms

    @property
    def name(self):
        """Gets the name of this CloudIntegration.  # noqa: E501

        The human-readable name of this integration  # noqa: E501

        :return: The name of this CloudIntegration.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this CloudIntegration.

        The human-readable name of this integration  # noqa: E501

        :param name: The name of this CloudIntegration.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def new_relic(self):
        """Gets the new_relic of this CloudIntegration.  # noqa: E501


        :return: The new_relic of this CloudIntegration.  # noqa: E501
        :rtype: NewRelicConfiguration
        """
        return self._new_relic

    @new_relic.setter
    def new_relic(self, new_relic):
        """Sets the new_relic of this CloudIntegration.


        :param new_relic: The new_relic of this CloudIntegration.  # noqa: E501
        :type: NewRelicConfiguration
        """

        self._new_relic = new_relic

    @property
    def reuse_external_id_credential(self):
        """Gets the reuse_external_id_credential of this CloudIntegration.  # noqa: E501


        :return: The reuse_external_id_credential of this CloudIntegration.  # noqa: E501
        :rtype: str
        """
        return self._reuse_external_id_credential

    @reuse_external_id_credential.setter
    def reuse_external_id_credential(self, reuse_external_id_credential):
        """Sets the reuse_external_id_credential of this CloudIntegration.


        :param reuse_external_id_credential: The reuse_external_id_credential of this CloudIntegration.  # noqa: E501
        :type: str
        """

        self._reuse_external_id_credential = reuse_external_id_credential

    @property
    def service(self):
        """Gets the service of this CloudIntegration.  # noqa: E501

        A value denoting which cloud service this integration integrates with  # noqa: E501

        :return: The service of this CloudIntegration.  # noqa: E501
        :rtype: str
        """
        return self._service

    @service.setter
    def service(self, service):
        """Sets the service of this CloudIntegration.

        A value denoting which cloud service this integration integrates with  # noqa: E501

        :param service: The service of this CloudIntegration.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and service is None:
            raise ValueError("Invalid value for `service`, must not be `None`")  # noqa: E501
        allowed_values = ["CLOUDWATCH", "CLOUDTRAIL", "EC2", "GCP", "GCPBILLING", "TESLA", "AZURE", "AZUREACTIVITYLOG", "NEWRELIC", "APPDYNAMICS"]  # noqa: E501
        if (self._configuration.client_side_validation and
                service not in allowed_values):
            raise ValueError(
                "Invalid value for `service` ({0}), must be one of {1}"  # noqa: E501
                .format(service, allowed_values)
            )

        self._service = service

    @property
    def service_refresh_rate_in_mins(self):
        """Gets the service_refresh_rate_in_mins of this CloudIntegration.  # noqa: E501

        Service refresh rate in minutes.  # noqa: E501

        :return: The service_refresh_rate_in_mins of this CloudIntegration.  # noqa: E501
        :rtype: int
        """
        return self._service_refresh_rate_in_mins

    @service_refresh_rate_in_mins.setter
    def service_refresh_rate_in_mins(self, service_refresh_rate_in_mins):
        """Sets the service_refresh_rate_in_mins of this CloudIntegration.

        Service refresh rate in minutes.  # noqa: E501

        :param service_refresh_rate_in_mins: The service_refresh_rate_in_mins of this CloudIntegration.  # noqa: E501
        :type: int
        """

        self._service_refresh_rate_in_mins = service_refresh_rate_in_mins

    @property
    def tesla(self):
        """Gets the tesla of this CloudIntegration.  # noqa: E501


        :return: The tesla of this CloudIntegration.  # noqa: E501
        :rtype: TeslaConfiguration
        """
        return self._tesla

    @tesla.setter
    def tesla(self, tesla):
        """Sets the tesla of this CloudIntegration.


        :param tesla: The tesla of this CloudIntegration.  # noqa: E501
        :type: TeslaConfiguration
        """

        self._tesla = tesla

    @property
    def updated_epoch_millis(self):
        """Gets the updated_epoch_millis of this CloudIntegration.  # noqa: E501


        :return: The updated_epoch_millis of this CloudIntegration.  # noqa: E501
        :rtype: int
        """
        return self._updated_epoch_millis

    @updated_epoch_millis.setter
    def updated_epoch_millis(self, updated_epoch_millis):
        """Sets the updated_epoch_millis of this CloudIntegration.


        :param updated_epoch_millis: The updated_epoch_millis of this CloudIntegration.  # noqa: E501
        :type: int
        """

        self._updated_epoch_millis = updated_epoch_millis

    @property
    def updater_id(self):
        """Gets the updater_id of this CloudIntegration.  # noqa: E501


        :return: The updater_id of this CloudIntegration.  # noqa: E501
        :rtype: str
        """
        return self._updater_id

    @updater_id.setter
    def updater_id(self, updater_id):
        """Sets the updater_id of this CloudIntegration.


        :param updater_id: The updater_id of this CloudIntegration.  # noqa: E501
        :type: str
        """

        self._updater_id = updater_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(CloudIntegration, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CloudIntegration):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, CloudIntegration):
            return True

        return self.to_dict() != other.to_dict()
